@@ -296,8 +296,8 @@ def post_collect_aws_profiles(config: dict, arguments: argparse.Namespace, profi
     logger.info('Post collect AWS profiles')
     if arguments.list_profiles:
         logger.debug('Listing profiles')
-        profile_lib.list_profile_data(profiles, arguments.list_profiles == 'more')
-        raise exceptions.EarlyExit()
+        profiles = profile_lib.list_profile_data(profiles, arguments.list_profiles == 'more', config)
+        raise exceptions.EarlyExit(data={'profiles': profiles})
 
 
 def assume_role_from_cli(config: dict, arguments: dict, profiles: dict):
@@ -579,6 +579,7 @@ def get_credentials(config: dict, arguments: argparse.Namespace, profiles: dict)
         target_profile_name = arguments.role_arn
     else:
         target_profile_name = get_profile_name(config, profiles, arguments.target_profile_name)
+    arguments.target_profile_name = target_profile_name
     role_chain = get_role_chain(config, arguments, profiles, target_profile_name)
     logger.debug('Role chain: {}'.format(role_chain))
     credentials = None
